@@ -88,6 +88,12 @@ class LAMP_MT_sunsky_presets(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -136,7 +142,8 @@ class LAMP_MT_sunsky_presets(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -237,6 +244,12 @@ class DATA_PT_area(DataButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -390,6 +403,12 @@ class DATA_PT_context_lamp(DataButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -543,6 +562,12 @@ class DATA_PT_custom_props_lamp(DataButtonsPanel, rna_prop_ui.PropertyPanel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -696,6 +721,12 @@ class DATA_PT_falloff_curve(DataButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -845,6 +876,12 @@ class DATA_PT_lamp(DataButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -994,6 +1031,12 @@ class DATA_PT_preview(DataButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1143,6 +1186,12 @@ class DATA_PT_shadow(DataButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1292,6 +1341,12 @@ class DATA_PT_spot(DataButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1441,6 +1496,12 @@ class DATA_PT_sunsky(DataButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
