@@ -62,6 +62,12 @@ class MATERIAL_MT_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -110,7 +116,8 @@ class MATERIAL_MT_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -217,6 +224,12 @@ class MATERIAL_MT_sss_presets(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -265,7 +278,8 @@ class MATERIAL_MT_sss_presets(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -352,6 +366,12 @@ class MATERIAL_UL_matslots(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -536,6 +556,12 @@ class MATERIAL_PT_context_material(MaterialButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -689,6 +715,12 @@ class MATERIAL_PT_custom_props(MaterialButtonsPanel, rna_prop_ui.PropertyPanel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -839,6 +871,12 @@ class MATERIAL_PT_diffuse(MaterialButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -995,6 +1033,12 @@ class MATERIAL_PT_flare(MaterialButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1145,6 +1189,12 @@ class MATERIAL_PT_game_settings(MaterialButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1295,6 +1345,12 @@ class MATERIAL_PT_halo(MaterialButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1454,6 +1510,12 @@ class MATERIAL_PT_mirror(MaterialButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1604,6 +1666,12 @@ class MATERIAL_PT_options(MaterialButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1760,6 +1828,12 @@ class MATERIAL_PT_physics(MaterialButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1913,6 +1987,12 @@ class MATERIAL_PT_pipeline(MaterialButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2063,6 +2143,12 @@ class MATERIAL_PT_preview(MaterialButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2213,6 +2299,12 @@ class MATERIAL_PT_shading(MaterialButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2366,6 +2458,12 @@ class MATERIAL_PT_shadow(MaterialButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2516,6 +2614,12 @@ class MATERIAL_PT_specular(MaterialButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2675,6 +2779,12 @@ class MATERIAL_PT_sss(MaterialButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2828,6 +2938,12 @@ class MATERIAL_PT_strand(MaterialButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2984,6 +3100,12 @@ class MATERIAL_PT_transp(MaterialButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3143,6 +3265,12 @@ class MATERIAL_PT_transp_game(MaterialButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3293,6 +3421,12 @@ class MATERIAL_PT_volume_density(VolumeButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3443,6 +3577,12 @@ class MATERIAL_PT_volume_integration(VolumeButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3593,6 +3733,12 @@ class MATERIAL_PT_volume_lighting(VolumeButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3746,6 +3892,12 @@ class MATERIAL_PT_volume_options(VolumeButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3896,6 +4048,12 @@ class MATERIAL_PT_volume_shading(VolumeButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -4046,6 +4204,12 @@ class MATERIAL_PT_volume_transp(VolumeButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
