@@ -67,6 +67,12 @@ class RENDER_MT_ffmpeg_presets(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -115,7 +121,8 @@ class RENDER_MT_ffmpeg_presets(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -222,6 +229,12 @@ class RENDER_MT_framerate_presets(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -270,7 +283,8 @@ class RENDER_MT_framerate_presets(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -377,6 +391,12 @@ class RENDER_MT_presets(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -425,7 +445,8 @@ class RENDER_MT_presets(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -550,6 +571,12 @@ class RENDER_PT_antialiasing(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -703,6 +730,12 @@ class RENDER_PT_bake(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -859,6 +892,12 @@ class RENDER_PT_dimensions(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1012,6 +1051,12 @@ class RENDER_PT_encoding(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1171,6 +1216,12 @@ class RENDER_PT_motion_blur(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1321,6 +1372,12 @@ class RENDER_PT_output(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1474,6 +1531,12 @@ class RENDER_PT_performance(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1627,6 +1690,12 @@ class RENDER_PT_post_processing(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1777,6 +1846,12 @@ class RENDER_PT_render(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1930,6 +2005,12 @@ class RENDER_PT_shading(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2083,6 +2164,12 @@ class RENDER_PT_stamp(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
