@@ -68,6 +68,12 @@ class SCENE_MT_units_length_presets(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -116,7 +122,8 @@ class SCENE_MT_units_length_presets(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -203,6 +210,12 @@ class SCENE_UL_keying_set_paths(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -374,6 +387,12 @@ class SCENE_PT_audio(SceneButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -527,6 +546,12 @@ class SCENE_PT_color_management(SceneButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -680,6 +705,12 @@ class SCENE_PT_custom_props(SceneButtonsPanel, rna_prop_ui.PropertyPanel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -836,6 +867,12 @@ class SCENE_PT_physics(SceneButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -989,6 +1026,12 @@ class SCENE_PT_rigid_body_cache(SceneButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1142,6 +1185,12 @@ class SCENE_PT_rigid_body_field_weights(SceneButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1298,6 +1347,12 @@ class SCENE_PT_rigid_body_world(SceneButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1447,6 +1502,12 @@ class SCENE_PT_scene(SceneButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1603,6 +1664,12 @@ class SCENE_PT_simplify(SceneButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1752,6 +1819,12 @@ class SCENE_PT_unit(SceneButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1908,6 +1981,12 @@ class SCENE_PT_keying_set_paths(SceneKeyingSetsPanel, SceneButtonsPanel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2064,6 +2143,12 @@ class SCENE_PT_keying_sets(SceneKeyingSetsPanel, SceneButtonsPanel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
