@@ -50,6 +50,12 @@ class NODE_HT_header(bpy_types.Header, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -196,6 +202,12 @@ class NODE_MT_add(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -244,7 +256,8 @@ class NODE_MT_add(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -354,6 +367,12 @@ class NODE_MT_editor_menus(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -402,7 +421,8 @@ class NODE_MT_editor_menus(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -503,6 +523,12 @@ class NODE_MT_node(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -551,7 +577,8 @@ class NODE_MT_node(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -658,6 +685,12 @@ class NODE_MT_node_color_presets(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -706,7 +739,8 @@ class NODE_MT_node_color_presets(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -807,6 +841,12 @@ class NODE_MT_node_color_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -855,7 +895,8 @@ class NODE_MT_node_color_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -956,6 +997,12 @@ class NODE_MT_select(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1004,7 +1051,8 @@ class NODE_MT_select(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -1105,6 +1153,12 @@ class NODE_MT_view(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1153,7 +1207,8 @@ class NODE_MT_view(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -1257,6 +1312,12 @@ class NODE_PT_active_node_color(bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1400,6 +1461,12 @@ class NODE_PT_active_node_generic(bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1543,6 +1610,12 @@ class NODE_PT_active_node_properties(bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1692,6 +1765,12 @@ class NODE_PT_backdrop(bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1855,6 +1934,12 @@ class NODE_PT_grease_pencil(
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2006,6 +2091,12 @@ class NODE_PT_grease_pencil_palettecolor(
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2154,6 +2245,12 @@ class NODE_PT_grease_pencil_tools(
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2297,6 +2394,12 @@ class NODE_PT_quality(bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2445,6 +2548,12 @@ class NODE_PT_tools_grease_pencil_brush(
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2590,6 +2699,12 @@ class NODE_PT_tools_grease_pencil_brushcurves(
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2738,6 +2853,12 @@ class NODE_PT_tools_grease_pencil_draw(
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2883,6 +3004,12 @@ class NODE_PT_tools_grease_pencil_edit(
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3031,6 +3158,12 @@ class NODE_PT_tools_grease_pencil_sculpt(
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3166,6 +3299,12 @@ class NODE_UL_interface_sockets(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
