@@ -51,6 +51,12 @@ class SEQUENCER_HT_header(bpy_types.Header, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -194,6 +200,12 @@ class SEQUENCER_MT_add(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -242,7 +254,8 @@ class SEQUENCER_MT_add(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -343,6 +356,12 @@ class SEQUENCER_MT_add_effect(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -391,7 +410,8 @@ class SEQUENCER_MT_add_effect(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -492,6 +512,12 @@ class SEQUENCER_MT_change(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -540,7 +566,8 @@ class SEQUENCER_MT_change(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -650,6 +677,12 @@ class SEQUENCER_MT_editor_menus(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -698,7 +731,8 @@ class SEQUENCER_MT_editor_menus(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -799,6 +833,12 @@ class SEQUENCER_MT_frame(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -847,7 +887,8 @@ class SEQUENCER_MT_frame(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -948,6 +989,12 @@ class SEQUENCER_MT_marker(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -996,7 +1043,8 @@ class SEQUENCER_MT_marker(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -1097,6 +1145,12 @@ class SEQUENCER_MT_select(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1145,7 +1199,8 @@ class SEQUENCER_MT_select(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -1246,6 +1301,12 @@ class SEQUENCER_MT_strip(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1294,7 +1355,8 @@ class SEQUENCER_MT_strip(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -1395,6 +1457,12 @@ class SEQUENCER_MT_view(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1443,7 +1511,8 @@ class SEQUENCER_MT_view(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -1544,6 +1613,12 @@ class SEQUENCER_MT_view_toggle(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1592,7 +1667,8 @@ class SEQUENCER_MT_view_toggle(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -1681,6 +1757,9 @@ class SEQUENCER_PT_custom_props(SequencerButtonsPanel,
     COMPAT_ENGINES = None
     ''' '''
 
+    bl_category = None
+    ''' '''
+
     bl_label = None
     ''' '''
 
@@ -1741,6 +1820,12 @@ class SEQUENCER_PT_custom_props(SequencerButtonsPanel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1834,6 +1919,9 @@ class SEQUENCER_PT_custom_props(SequencerButtonsPanel,
 
 class SEQUENCER_PT_edit(SequencerButtonsPanel, bpy_types.Panel,
                         bpy_types._GenericUI):
+    bl_category = None
+    ''' '''
+
     bl_label = None
     ''' '''
 
@@ -1891,6 +1979,12 @@ class SEQUENCER_PT_edit(SequencerButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1984,6 +2078,9 @@ class SEQUENCER_PT_edit(SequencerButtonsPanel, bpy_types.Panel,
 
 class SEQUENCER_PT_effect(SequencerButtonsPanel, bpy_types.Panel,
                           bpy_types._GenericUI):
+    bl_category = None
+    ''' '''
+
     bl_label = None
     ''' '''
 
@@ -2041,6 +2138,12 @@ class SEQUENCER_PT_effect(SequencerButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2134,6 +2237,9 @@ class SEQUENCER_PT_effect(SequencerButtonsPanel, bpy_types.Panel,
 
 class SEQUENCER_PT_filter(SequencerButtonsPanel, bpy_types.Panel,
                           bpy_types._GenericUI):
+    bl_category = None
+    ''' '''
+
     bl_label = None
     ''' '''
 
@@ -2191,6 +2297,12 @@ class SEQUENCER_PT_filter(SequencerButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2284,6 +2396,9 @@ class SEQUENCER_PT_filter(SequencerButtonsPanel, bpy_types.Panel,
 
 class SEQUENCER_PT_input(SequencerButtonsPanel, bpy_types.Panel,
                          bpy_types._GenericUI):
+    bl_category = None
+    ''' '''
+
     bl_label = None
     ''' '''
 
@@ -2341,6 +2456,12 @@ class SEQUENCER_PT_input(SequencerButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2434,6 +2555,9 @@ class SEQUENCER_PT_input(SequencerButtonsPanel, bpy_types.Panel,
 
 class SEQUENCER_PT_mask(SequencerButtonsPanel, bpy_types.Panel,
                         bpy_types._GenericUI):
+    bl_category = None
+    ''' '''
+
     bl_label = None
     ''' '''
 
@@ -2491,6 +2615,12 @@ class SEQUENCER_PT_mask(SequencerButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2584,6 +2714,9 @@ class SEQUENCER_PT_mask(SequencerButtonsPanel, bpy_types.Panel,
 
 class SEQUENCER_PT_modifiers(SequencerButtonsPanel, bpy_types.Panel,
                              bpy_types._GenericUI):
+    bl_category = None
+    ''' '''
+
     bl_label = None
     ''' '''
 
@@ -2641,6 +2774,12 @@ class SEQUENCER_PT_modifiers(SequencerButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2734,6 +2873,9 @@ class SEQUENCER_PT_modifiers(SequencerButtonsPanel, bpy_types.Panel,
 
 class SEQUENCER_PT_proxy(SequencerButtonsPanel, bpy_types.Panel,
                          bpy_types._GenericUI):
+    bl_category = None
+    ''' '''
+
     bl_label = None
     ''' '''
 
@@ -2797,6 +2939,12 @@ class SEQUENCER_PT_proxy(SequencerButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2890,6 +3038,9 @@ class SEQUENCER_PT_proxy(SequencerButtonsPanel, bpy_types.Panel,
 
 class SEQUENCER_PT_scene(SequencerButtonsPanel, bpy_types.Panel,
                          bpy_types._GenericUI):
+    bl_category = None
+    ''' '''
+
     bl_label = None
     ''' '''
 
@@ -2947,6 +3098,12 @@ class SEQUENCER_PT_scene(SequencerButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3040,6 +3197,9 @@ class SEQUENCER_PT_scene(SequencerButtonsPanel, bpy_types.Panel,
 
 class SEQUENCER_PT_sound(SequencerButtonsPanel, bpy_types.Panel,
                          bpy_types._GenericUI):
+    bl_category = None
+    ''' '''
+
     bl_label = None
     ''' '''
 
@@ -3097,6 +3257,12 @@ class SEQUENCER_PT_sound(SequencerButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3267,6 +3433,12 @@ class SEQUENCER_PT_grease_pencil(
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3425,6 +3597,12 @@ class SEQUENCER_PT_grease_pencil_palettecolor(
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3577,6 +3755,12 @@ class SEQUENCER_PT_grease_pencil_tools(
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3727,6 +3911,12 @@ class SEQUENCER_PT_preview(SequencerButtonsPanel_Output, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3877,6 +4067,12 @@ class SEQUENCER_PT_view(SequencerButtonsPanel_Output, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -4036,6 +4232,12 @@ class SEQUENCER_PT_view_safe_areas(SequencerButtonsPanel_Output,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
