@@ -65,11 +65,11 @@ def duplicate_move(ACTION_OT_duplicate=None, TRANSFORM_OT_transform=None):
     pass
 
 
-def extrapolation_type(type: typing.Union[str, int] = 'CONSTANT'):
+def extrapolation_type(type: typing.Union[int, str] = 'CONSTANT'):
     ''' Set extrapolation mode for selected F-Curves
 
     :param type: Type * CONSTANT Constant Extrapolation, Values on endpoint keyframes are held. * LINEAR Linear Extrapolation, Straight-line slope of end segments are extended past the endpoint keyframes. * MAKE_CYCLIC Make Cyclic (F-Modifier), Add Cycles F-Modifier if one doesn't exist already. * CLEAR_CYCLIC Clear Cyclic (F-Modifier), Remove Cycles F-Modifier if not needed anymore.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -83,41 +83,41 @@ def frame_jump():
     pass
 
 
-def handle_type(type: typing.Union[str, int] = 'FREE'):
+def handle_type(type: typing.Union[int, str] = 'FREE'):
     ''' Set type of handle for selected keyframes
 
     :param type: Type * FREE Free. * VECTOR Vector. * ALIGNED Aligned. * AUTO Automatic. * AUTO_CLAMPED Auto Clamped, Auto handles clamped to not overshoot.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
-def interpolation_type(type: typing.Union[str, int] = 'CONSTANT'):
+def interpolation_type(type: typing.Union[int, str] = 'CONSTANT'):
     ''' Set interpolation mode for the F-Curve segments starting from the selected keyframes
 
     :param type: Type * CONSTANT Constant, No interpolation, value of A gets held until B is encountered. * LINEAR Linear, Straight-line interpolation between A and B (i.e. no ease in/out). * BEZIER Bezier, Smooth interpolation between A and B, with some control over curve shape. * SINE Sinusoidal, Sinusoidal easing (weakest, almost linear but with a slight curvature). * QUAD Quadratic, Quadratic easing. * CUBIC Cubic, Cubic easing. * QUART Quartic, Quartic easing. * QUINT Quintic, Quintic easing. * EXPO Exponential, Exponential easing (dramatic). * CIRC Circular, Circular easing (strongest and most dynamic). * BACK Back, Cubic easing with overshoot and settle. * BOUNCE Bounce, Exponentially decaying parabolic bounce, like when objects collide. * ELASTIC Elastic, Exponentially decaying sine wave, like an elastic band.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
-def keyframe_insert(type: typing.Union[str, int] = 'ALL'):
+def keyframe_insert(type: typing.Union[int, str] = 'ALL'):
     ''' Insert keyframes for the specified channels
 
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
-def keyframe_type(type: typing.Union[str, int] = 'KEYFRAME'):
+def keyframe_type(type: typing.Union[int, str] = 'KEYFRAME'):
     ''' Set type of keyframe for the selected keyframes
 
     :param type: Type * KEYFRAME Keyframe, Normal keyframe - e.g. for key poses. * BREAKDOWN Breakdown, A breakdown pose - e.g. for transitions between key poses. * MOVING_HOLD Moving Hold, A keyframe that is part of a moving hold. * EXTREME Extreme, An 'extreme' pose, or some other purpose as needed. * JITTER Jitter, A filler or baked keyframe for keying on ones, or some other purpose as needed.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -147,11 +147,11 @@ def markers_make_local():
     pass
 
 
-def mirror(type: typing.Union[str, int] = 'CFRA'):
+def mirror(type: typing.Union[int, str] = 'CFRA'):
     ''' Flip selected keyframes over the selected mirror line
 
     :param type: Type * CFRA By Times over Current frame, Flip times of selected keyframes using the current frame as the mirror line. * XAXIS By Values over Value=0, Flip values of selected keyframes (i.e. negative values become positive, and vice versa). * MARKER By Times over First Selected Marker, Flip times of selected keyframes using the first selected marker as the reference point.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -165,15 +165,15 @@ def new():
     pass
 
 
-def paste(offset: typing.Union[str, int] = 'START',
-          merge: typing.Union[str, int] = 'MIX',
+def paste(offset: typing.Union[int, str] = 'START',
+          merge: typing.Union[int, str] = 'MIX',
           flipped: bool = False):
     ''' Paste keyframes from copy/paste buffer for the selected channels, starting on the current frame
 
     :param offset: Offset, Paste time offset of keys * START Frame Start, Paste keys starting at current frame. * END Frame End, Paste keys ending at current frame. * RELATIVE Frame Relative, Paste keys relative to the current frame when copying. * NONE No Offset, Paste keys from original time.
-    :type offset: typing.Union[str, int]
+    :type offset: typing.Union[int, str]
     :param merge: Type, Method of merging pasted keys and existing * MIX Mix, Overlay existing with new keys. * OVER_ALL Overwrite All, Replace all keys. * OVER_RANGE Overwrite Range, Overwrite keys in pasted range. * OVER_RANGE_ALL Overwrite Entire Range, Overwrite keys in pasted range, using the range of all copied keys.
-    :type merge: typing.Union[str, int]
+    :type merge: typing.Union[int, str]
     :param flipped: Flipped, Paste keyframes from mirrored bones if they exist
     :type flipped: bool
     '''
@@ -270,24 +270,25 @@ def select_circle(x: int = 0,
     pass
 
 
-def select_column(mode: typing.Union[str, int] = 'KEYS'):
+def select_column(mode: typing.Union[int, str] = 'KEYS'):
     ''' Select all keyframes on the specified frame(s)
 
     :param mode: Mode
-    :type mode: typing.Union[str, int]
+    :type mode: typing.Union[int, str]
     '''
 
     pass
 
 
-def select_lasso(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                                    'bpy_prop_collection'] = None,
+def select_lasso(path: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
                  deselect: bool = False,
                  extend: bool = True):
     ''' Select keyframe points using lasso selection
 
     :param path: Path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param deselect: Deselect, Deselect rather than select items
     :type deselect: bool
     :param extend: Extend, Extend selection instead of deselecting everything first
@@ -297,12 +298,12 @@ def select_lasso(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
     pass
 
 
-def select_leftright(mode: typing.Union[str, int] = 'CHECK',
+def select_leftright(mode: typing.Union[int, str] = 'CHECK',
                      extend: bool = False):
     ''' Select keyframes to the left or the right of the current frame
 
     :param mode: Mode
-    :type mode: typing.Union[str, int]
+    :type mode: typing.Union[int, str]
     :param extend: Extend Select
     :type extend: bool
     '''
@@ -334,11 +335,11 @@ def select_more():
     pass
 
 
-def snap(type: typing.Union[str, int] = 'CFRA'):
+def snap(type: typing.Union[int, str] = 'CFRA'):
     ''' Snap selected keyframes to the times specified
 
     :param type: Type * CFRA Current frame, Snap selected keyframes to the current frame. * NEAREST_FRAME Nearest Frame, Snap selected keyframes to the nearest (whole) frame (use to fix accidental sub-frame offsets). * NEAREST_SECOND Nearest Second, Snap selected keyframes to the nearest second. * NEAREST_MARKER Nearest Marker, Snap selected keyframes to the nearest marker.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
