@@ -2,11 +2,11 @@ import sys
 import typing
 
 
-def change_frame(frame: int = 0, snap: bool = False):
+def change_frame(frame: float = 0.0, snap: bool = False):
     ''' Interactively change the current frame number
 
     :param frame: Frame
-    :type frame: int
+    :type frame: float
     :param snap: Snap
     :type snap: bool
     '''
@@ -25,7 +25,7 @@ def channel_select_keys(extend: bool = False):
 
 
 def channels_clean_empty():
-    ''' Delete all empty animation data containers from visible datablocks
+    ''' Delete all empty animation data containers from visible data-blocks
 
     '''
 
