@@ -39,7 +39,7 @@ def bookmark_delete(index: int = -1):
 def bookmark_move(direction: typing.Union[int, str] = 'TOP'):
     ''' Move the active bookmark up/down in the list
 
-    :param direction: Direction, Direction to move, UP or DOWN * TOP Top, Top of the list. * UP Up. * DOWN Down. * BOTTOM Bottom, Bottom of the list.
+    :param direction: Direction, Direction to move the active bookmark towards * TOP Top, Top of the list. * UP Up. * DOWN Down. * BOTTOM Bottom, Bottom of the list.
     :type direction: typing.Union[int, str]
     '''
 
