@@ -283,7 +283,7 @@ def textbox_remove(index: int = 0):
 
 
 def unlink():
-    ''' Unlink active font data block
+    ''' Unlink active font data-block
 
     '''
 
