@@ -3,13 +3,13 @@ import typing
 import bpy.types
 
 
-def actuator_add(type: typing.Union[str, int] = '',
+def actuator_add(type: typing.Union[int, str] = '',
                  name: str = "",
                  object: str = ""):
     ''' Add an actuator to the active object
 
     :param type: Type, Type of actuator to add
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param name: Name, Name of the Actuator to add
     :type name: str
     :param object: Object, Name of the Object to add the Actuator to
@@ -21,7 +21,7 @@ def actuator_add(type: typing.Union[str, int] = '',
 
 def actuator_move(actuator: str = "",
                   object: str = "",
-                  direction: typing.Union[str, int] = 'UP'):
+                  direction: typing.Union[int, str] = 'UP'):
     ''' Move Actuator
 
     :param actuator: Actuator, Name of the actuator to edit
@@ -29,7 +29,7 @@ def actuator_move(actuator: str = "",
     :param object: Object, Name of the object the actuator belongs to
     :type object: str
     :param direction: Direction, Move Up or Down
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Union[int, str]
     '''
 
     pass
@@ -47,13 +47,13 @@ def actuator_remove(actuator: str = "", object: str = ""):
     pass
 
 
-def controller_add(type: typing.Union[str, int] = 'LOGIC_AND',
+def controller_add(type: typing.Union[int, str] = 'LOGIC_AND',
                    name: str = "",
                    object: str = ""):
     ''' Add a controller to the active object
 
     :param type: Type, Type of controller to add * LOGIC_AND And, Logic And. * LOGIC_OR Or, Logic Or. * LOGIC_NAND Nand, Logic Nand. * LOGIC_NOR Nor, Logic Nor. * LOGIC_XOR Xor, Logic Xor. * LOGIC_XNOR Xnor, Logic Xnor. * EXPRESSION Expression. * PYTHON Python.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param name: Name, Name of the Controller to add
     :type name: str
     :param object: Object, Name of the Object to add the Controller to
@@ -65,7 +65,7 @@ def controller_add(type: typing.Union[str, int] = 'LOGIC_AND',
 
 def controller_move(controller: str = "",
                     object: str = "",
-                    direction: typing.Union[str, int] = 'UP'):
+                    direction: typing.Union[int, str] = 'UP'):
     ''' Move Controller
 
     :param controller: Controller, Name of the controller to edit
@@ -73,7 +73,7 @@ def controller_move(controller: str = "",
     :param object: Object, Name of the object the controller belongs to
     :type object: str
     :param direction: Direction, Move Up or Down
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Union[int, str]
     '''
 
     pass
@@ -114,13 +114,13 @@ def properties():
     pass
 
 
-def sensor_add(type: typing.Union[str, int] = '',
+def sensor_add(type: typing.Union[int, str] = '',
                name: str = "",
                object: str = ""):
     ''' Add a sensor to the active object
 
     :param type: Type, Type of sensor to add
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param name: Name, Name of the Sensor to add
     :type name: str
     :param object: Object, Name of the Object to add the Sensor to
@@ -132,7 +132,7 @@ def sensor_add(type: typing.Union[str, int] = '',
 
 def sensor_move(sensor: str = "",
                 object: str = "",
-                direction: typing.Union[str, int] = 'UP'):
+                direction: typing.Union[int, str] = 'UP'):
     ''' Move Sensor
 
     :param sensor: Sensor, Name of the sensor to edit
@@ -140,7 +140,7 @@ def sensor_move(sensor: str = "",
     :param object: Object, Name of the object the sensor belongs to
     :type object: str
     :param direction: Direction, Move Up or Down
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Union[int, str]
     '''
 
     pass
