@@ -12,7 +12,7 @@ def beautify_fill(angle_limit: float = 3.14159):
     pass
 
 
-def bevel(offset_type: typing.Union[str, int] = 'OFFSET',
+def bevel(offset_type: typing.Union[int, str] = 'OFFSET',
           offset: float = 0.0,
           segments: int = 1,
           profile: float = 0.5,
@@ -23,7 +23,7 @@ def bevel(offset_type: typing.Union[str, int] = 'OFFSET',
     ''' Edge Bevel
 
     :param offset_type: Amount Type, What distance Amount measures * OFFSET Offset, Amount is offset of new edges from original. * WIDTH Width, Amount is width of new face. * DEPTH Depth, Amount is perpendicular distance from original edge to bevel face. * PERCENT Percent, Amount is percent of adjacent edge length.
-    :type offset_type: typing.Union[str, int]
+    :type offset_type: typing.Union[int, str]
     :param offset: Amount
     :type offset: float
     :param segments: Segments, Segments for curved edge
@@ -83,13 +83,13 @@ def bisect(plane_co: typing.List[float] = (0.0, 0.0, 0.0),
     pass
 
 
-def blend_from_shape(shape: typing.Union[str, int] = '',
+def blend_from_shape(shape: typing.Union[int, str] = '',
                      blend: float = 1.0,
                      add: bool = True):
     ''' Blend in shape from a shape key
 
     :param shape: Shape, Shape key to use for blending
-    :type shape: typing.Union[str, int]
+    :type shape: typing.Union[int, str]
     :param blend: Blend, Blending factor
     :type blend: float
     :param add: Add, Add rather than blend between shapes
@@ -99,19 +99,19 @@ def blend_from_shape(shape: typing.Union[str, int] = '',
     pass
 
 
-def bridge_edge_loops(type: typing.Union[str, int] = 'SINGLE',
+def bridge_edge_loops(type: typing.Union[int, str] = 'SINGLE',
                       use_merge: bool = False,
                       merge_factor: float = 0.5,
                       twist_offset: int = 0,
                       number_cuts: int = 0,
-                      interpolation: typing.Union[str, int] = 'PATH',
+                      interpolation: typing.Union[int, str] = 'PATH',
                       smoothness: float = 1.0,
                       profile_shape_factor: float = 0.0,
-                      profile_shape: typing.Union[str, int] = 'SMOOTH'):
+                      profile_shape: typing.Union[int, str] = 'SMOOTH'):
     ''' Make faces between two or more edge loops
 
     :param type: Connect Loops, Method of bridging multiple loops
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param use_merge: Merge, Merge rather than creating faces
     :type use_merge: bool
     :param merge_factor: Merge Factor
@@ -121,13 +121,13 @@ def bridge_edge_loops(type: typing.Union[str, int] = 'SINGLE',
     :param number_cuts: Number of Cuts
     :type number_cuts: int
     :param interpolation: Interpolation, Interpolation method
-    :type interpolation: typing.Union[str, int]
+    :type interpolation: typing.Union[int, str]
     :param smoothness: Smoothness, Smoothness factor
     :type smoothness: float
     :param profile_shape_factor: Profile Factor, How much intermediary new edges are shrunk/expanded
     :type profile_shape_factor: float
     :param profile_shape: Profile Shape, Shape of the profile * SMOOTH Smooth, Smooth falloff. * SPHERE Sphere, Spherical falloff. * ROOT Root, Root falloff. * INVERSE_SQUARE Inverse Square, Inverse Square falloff. * SHARP Sharp, Sharp falloff. * LINEAR Linear, Linear falloff.
-    :type profile_shape: typing.Union[str, int]
+    :type profile_shape: typing.Union[int, str]
     '''
 
     pass
@@ -236,7 +236,7 @@ def decimate(ratio: float = 1.0,
              vertex_group_factor: float = 1.0,
              invert_vertex_group: bool = False,
              use_symmetry: bool = False,
-             symmetry_axis: typing.Union[str, int] = 'Y'):
+             symmetry_axis: typing.Union[int, str] = 'Y'):
     ''' Simplify geometry by collapsing edges
 
     :param ratio: Ratio
@@ -250,17 +250,17 @@ def decimate(ratio: float = 1.0,
     :param use_symmetry: Symmetry, Maintain symmetry on an axis
     :type use_symmetry: bool
     :param symmetry_axis: Axis, Axis of symmetry
-    :type symmetry_axis: typing.Union[str, int]
+    :type symmetry_axis: typing.Union[int, str]
     '''
 
     pass
 
 
-def delete(type: typing.Union[str, int] = 'VERT'):
+def delete(type: typing.Union[int, str] = 'VERT'):
     ''' Delete selected vertices, edges or faces
 
     :param type: Type, Method used for deleting mesh data
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -327,7 +327,7 @@ def dissolve_faces(use_verts: bool = False):
 def dissolve_limited(
         angle_limit: float = 0.0872665,
         use_dissolve_boundaries: bool = False,
-        delimit: typing.Union[typing.Set[str], typing.Set[int]] = {'NORMAL'}):
+        delimit: typing.Union[typing.Set[int], typing.Set[str]] = {'NORMAL'}):
     ''' Dissolve selected edges and verts, limited by the angle of surrounding geometry
 
     :param angle_limit: Max Angle, Angle limit
@@ -335,7 +335,7 @@ def dissolve_limited(
     :param use_dissolve_boundaries: All Boundaries, Dissolve all vertices inbetween face boundaries
     :type use_dissolve_boundaries: bool
     :param delimit: Delimit, Delimit dissolve operation * NORMAL Normal, Delimit by face directions. * MATERIAL Material, Delimit by face material. * SEAM Seam, Delimit by edge seams. * SHARP Sharp, Delimit by sharp edges. * UV UVs, Delimit by UV coordinates.
-    :type delimit: typing.Union[typing.Set[str], typing.Set[int]]
+    :type delimit: typing.Union[typing.Set[int], typing.Set[str]]
     '''
 
     pass
@@ -606,12 +606,12 @@ def face_split_by_edges():
     pass
 
 
-def faces_mirror_uv(direction: typing.Union[str, int] = 'POSITIVE',
+def faces_mirror_uv(direction: typing.Union[int, str] = 'POSITIVE',
                     precision: int = 3):
     ''' Copy mirror UV coordinates on the X axis based on a mirrored mesh
 
     :param direction: Axis Direction
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Union[int, str]
     :param precision: Precision, Tolerance for finding vertex duplicates
     :type precision: int
     '''
@@ -734,15 +734,15 @@ def inset(use_boundary: bool = True,
     pass
 
 
-def intersect(mode: typing.Union[str, int] = 'SELECT_UNSELECT',
-              separate_mode: typing.Union[str, int] = 'CUT',
+def intersect(mode: typing.Union[int, str] = 'SELECT_UNSELECT',
+              separate_mode: typing.Union[int, str] = 'CUT',
               threshold: float = 1e-06):
     ''' Cut an intersection into faces
 
     :param mode: Source * SELECT Self Intersect, Self intersect selected faces. * SELECT_UNSELECT Selected/Unselected, Intersect selected with unselected faces.
-    :type mode: typing.Union[str, int]
+    :type mode: typing.Union[int, str]
     :param separate_mode: Separate Mode * ALL All, Separate all geometry from intersections. * CUT Cut, Cut into geometry keeping each side separate (Selected/Unselected only). * NONE Merge, Merge all geometry from the intersection.
-    :type separate_mode: typing.Union[str, int]
+    :type separate_mode: typing.Union[int, str]
     :param threshold: Merge threshold
     :type threshold: float
     '''
@@ -750,13 +750,13 @@ def intersect(mode: typing.Union[str, int] = 'SELECT_UNSELECT',
     pass
 
 
-def intersect_boolean(operation: typing.Union[str, int] = 'DIFFERENCE',
+def intersect_boolean(operation: typing.Union[int, str] = 'DIFFERENCE',
                       use_swap: bool = False,
                       threshold: float = 1e-06):
     ''' Cut solid geometry from selected to unselected
 
     :param operation: Boolean
-    :type operation: typing.Union[str, int]
+    :type operation: typing.Union[int, str]
     :param use_swap: Swap, Use with difference intersection to swap which side is kept
     :type use_swap: bool
     :param threshold: Merge threshold
@@ -829,7 +829,7 @@ def loop_to_region(select_bigger: bool = False):
 
 def loopcut(number_cuts: int = 1,
             smoothness: float = 0.0,
-            falloff: typing.Union[str, int] = 'INVERSE_SQUARE',
+            falloff: typing.Union[int, str] = 'INVERSE_SQUARE',
             edge_index: int = -1,
             mesh_select_mode_init: typing.List[bool] = (False, False, False)):
     ''' Add a new loop between existing loops
@@ -839,7 +839,7 @@ def loopcut(number_cuts: int = 1,
     :param smoothness: Smoothness, Smoothness factor
     :type smoothness: float
     :param falloff: Falloff, Falloff type the feather * SMOOTH Smooth, Smooth falloff. * SPHERE Sphere, Spherical falloff. * ROOT Root, Root falloff. * INVERSE_SQUARE Inverse Square, Inverse Square falloff. * SHARP Sharp, Sharp falloff. * LINEAR Linear, Linear falloff.
-    :type falloff: typing.Union[str, int]
+    :type falloff: typing.Union[int, str]
     :param edge_index: Edge Index
     :type edge_index: int
     :type mesh_select_mode_init: typing.List[bool]
@@ -900,11 +900,11 @@ def mark_sharp(clear: bool = False, use_verts: bool = False):
     pass
 
 
-def merge(type: typing.Union[str, int] = 'CENTER', uvs: bool = False):
+def merge(type: typing.Union[int, str] = 'CENTER', uvs: bool = False):
     ''' Merge selected vertices
 
     :param type: Type, Merge method to use
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param uvs: UVs, Move UVs according to merge
     :type uvs: bool
     '''
@@ -995,7 +995,7 @@ def offset_edge_loops_slide(MESH_OT_offset_edge_loops=None,
 
 def poke(offset: float = 0.0,
          use_relative_offset: bool = False,
-         center_mode: typing.Union[str, int] = 'MEAN_WEIGHTED'):
+         center_mode: typing.Union[int, str] = 'MEAN_WEIGHTED'):
     ''' Split a face into a fan
 
     :param offset: Poke Offset, Poke Offset
@@ -1003,7 +1003,7 @@ def poke(offset: float = 0.0,
     :param use_relative_offset: Offset Relative, Scale the offset by surrounding geometry
     :type use_relative_offset: bool
     :param center_mode: Poke Center, Poke Face Center Calculation * MEAN_WEIGHTED Weighted Mean, Weighted Mean Face Center. * MEAN Mean, Mean Face Center. * BOUNDS Bounds, Face Bounds Center.
-    :type center_mode: typing.Union[str, int]
+    :type center_mode: typing.Union[int, str]
     '''
 
     pass
@@ -1012,7 +1012,7 @@ def poke(offset: float = 0.0,
 def primitive_circle_add(
         vertices: int = 32,
         radius: float = 1.0,
-        fill_type: typing.Union[str, int] = 'NOTHING',
+        fill_type: typing.Union[int, str] = 'NOTHING',
         calc_uvs: bool = False,
         view_align: bool = False,
         enter_editmode: bool = False,
@@ -1029,7 +1029,7 @@ def primitive_circle_add(
     :param radius: Radius
     :type radius: float
     :param fill_type: Fill Type * NOTHING Nothing, Don't fill at all. * NGON Ngon, Use ngons. * TRIFAN Triangle Fan, Use triangle fans.
-    :type fill_type: typing.Union[str, int]
+    :type fill_type: typing.Union[int, str]
     :param calc_uvs: Generate UVs, Generate a default UV map
     :type calc_uvs: bool
     :param view_align: Align to View, Align the new object to the view
@@ -1052,7 +1052,7 @@ def primitive_cone_add(
         radius1: float = 1.0,
         radius2: float = 0.0,
         depth: float = 2.0,
-        end_fill_type: typing.Union[str, int] = 'NGON',
+        end_fill_type: typing.Union[int, str] = 'NGON',
         calc_uvs: bool = False,
         view_align: bool = False,
         enter_editmode: bool = False,
@@ -1073,7 +1073,7 @@ def primitive_cone_add(
     :param depth: Depth
     :type depth: float
     :param end_fill_type: Base Fill Type * NOTHING Nothing, Don't fill at all. * NGON Ngon, Use ngons. * TRIFAN Triangle Fan, Use triangle fans.
-    :type end_fill_type: typing.Union[str, int]
+    :type end_fill_type: typing.Union[int, str]
     :param calc_uvs: Generate UVs, Generate a default UV map
     :type calc_uvs: bool
     :param view_align: Align to View, Align the new object to the view
@@ -1127,7 +1127,7 @@ def primitive_cylinder_add(
         vertices: int = 32,
         radius: float = 1.0,
         depth: float = 2.0,
-        end_fill_type: typing.Union[str, int] = 'NGON',
+        end_fill_type: typing.Union[int, str] = 'NGON',
         calc_uvs: bool = False,
         view_align: bool = False,
         enter_editmode: bool = False,
@@ -1146,7 +1146,7 @@ def primitive_cylinder_add(
     :param depth: Depth
     :type depth: float
     :param end_fill_type: Cap Fill Type * NOTHING Nothing, Don't fill at all. * NGON Ngon, Use ngons. * TRIFAN Triangle Fan, Use triangle fans.
-    :type end_fill_type: typing.Union[str, int]
+    :type end_fill_type: typing.Union[int, str]
     :param calc_uvs: Generate UVs, Generate a default UV map
     :type calc_uvs: bool
     :param view_align: Align to View, Align the new object to the view
@@ -1302,16 +1302,16 @@ def primitive_plane_add(
 
 
 def primitive_torus_add(
-        view_align: bool = False,
-        rotation: typing.List[float] = (0.0, 0.0, 0.0),
         layers: typing.List[bool] = (False, False, False, False, False, False,
                                      False, False, False, False, False, False,
                                      False, False, False, False, False, False,
                                      False, False),
+        view_align: bool = False,
         location: typing.List[float] = (0.0, 0.0, 0.0),
+        rotation: typing.List[float] = (0.0, 0.0, 0.0),
         major_segments: int = 48,
         minor_segments: int = 12,
-        mode: typing.Union[str, int] = 'MAJOR_MINOR',
+        mode: typing.Union[int, str] = 'MAJOR_MINOR',
         major_radius: float = 1.0,
         minor_radius: float = 0.25,
         abso_major_rad: float = 1.25,
@@ -1319,20 +1319,20 @@ def primitive_torus_add(
         generate_uvs: bool = False):
     ''' Add a torus mesh
 
-    :param view_align: Align to View
-    :type view_align: bool
-    :param rotation: Rotation
-    :type rotation: typing.List[float]
     :param layers: Layers
     :type layers: typing.List[bool]
+    :param view_align: Align to View
+    :type view_align: bool
     :param location: Location
     :type location: typing.List[float]
+    :param rotation: Rotation
+    :type rotation: typing.List[float]
     :param major_segments: Major Segments, Number of segments for the main ring of the torus
     :type major_segments: int
     :param minor_segments: Minor Segments, Number of segments for the minor ring of the torus
     :type minor_segments: int
     :param mode: Torus Dimensions * MAJOR_MINOR Major/Minor, Use the major/minor radii for torus dimensions. * EXT_INT Exterior/Interior, Use the exterior/interior radii for torus dimensions.
-    :type mode: typing.Union[str, int]
+    :type mode: typing.Union[int, str]
     :param major_radius: Major Radius, Radius from the origin to the center of the cross sections
     :type major_radius: float
     :param minor_radius: Minor Radius, Radius of the torus' cross section
@@ -1386,14 +1386,14 @@ def primitive_uv_sphere_add(
     pass
 
 
-def quads_convert_to_tris(quad_method: typing.Union[str, int] = 'BEAUTY',
-                          ngon_method: typing.Union[str, int] = 'BEAUTY'):
+def quads_convert_to_tris(quad_method: typing.Union[int, str] = 'BEAUTY',
+                          ngon_method: typing.Union[int, str] = 'BEAUTY'):
     ''' Triangulate selected faces
 
     :param quad_method: Quad Method, Method for splitting the quads into triangles * BEAUTY Beauty , Split the quads in nice triangles, slower method. * FIXED Fixed, Split the quads on the first and third vertices. * FIXED_ALTERNATE Fixed Alternate, Split the quads on the 2nd and 4th vertices. * SHORTEST_DIAGONAL Shortest Diagonal, Split the quads based on the distance between the vertices.
-    :type quad_method: typing.Union[str, int]
+    :type quad_method: typing.Union[int, str]
     :param ngon_method: Polygon Method, Method for splitting the polygons into triangles * BEAUTY Beauty, Arrange the new triangles evenly (slow). * CLIP Clip, Split the polygons with an ear clipping algorithm.
-    :type ngon_method: typing.Union[str, int]
+    :type ngon_method: typing.Union[int, str]
     '''
 
     pass
@@ -1428,8 +1428,8 @@ def reveal():
 
 
 def rip(mirror: bool = False,
-        proportional: typing.Union[str, int] = 'DISABLED',
-        proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
+        proportional: typing.Union[int, str] = 'DISABLED',
+        proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
         proportional_size: float = 1.0,
         release_confirm: bool = False,
         use_accurate: bool = False,
@@ -1439,9 +1439,9 @@ def rip(mirror: bool = False,
     :param mirror: Mirror Editing
     :type mirror: bool
     :param proportional: Proportional Editing * DISABLED Disable, Proportional Editing disabled. * ENABLED Enable, Proportional Editing enabled. * PROJECTED Projected (2D), Proportional Editing using screen space locations. * CONNECTED Connected, Proportional Editing using connected geometry only.
-    :type proportional: typing.Union[str, int]
+    :type proportional: typing.Union[int, str]
     :param proportional_edit_falloff: Proportional Editing Falloff, Falloff type for proportional editing mode * SMOOTH Smooth, Smooth falloff. * SPHERE Sphere, Spherical falloff. * ROOT Root, Root falloff. * INVERSE_SQUARE Inverse Square, Inverse Square falloff. * SHARP Sharp, Sharp falloff. * LINEAR Linear, Linear falloff. * CONSTANT Constant, Constant falloff. * RANDOM Random, Random falloff.
-    :type proportional_edit_falloff: typing.Union[str, int]
+    :type proportional_edit_falloff: typing.Union[int, str]
     :param proportional_size: Proportional Size
     :type proportional_size: float
     :param release_confirm: Confirm on Release, Always confirm operation when releasing button
@@ -1456,8 +1456,8 @@ def rip(mirror: bool = False,
 
 
 def rip_edge(mirror: bool = False,
-             proportional: typing.Union[str, int] = 'DISABLED',
-             proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
+             proportional: typing.Union[int, str] = 'DISABLED',
+             proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
              proportional_size: float = 1.0,
              release_confirm: bool = False,
              use_accurate: bool = False):
@@ -1466,9 +1466,9 @@ def rip_edge(mirror: bool = False,
     :param mirror: Mirror Editing
     :type mirror: bool
     :param proportional: Proportional Editing * DISABLED Disable, Proportional Editing disabled. * ENABLED Enable, Proportional Editing enabled. * PROJECTED Projected (2D), Proportional Editing using screen space locations. * CONNECTED Connected, Proportional Editing using connected geometry only.
-    :type proportional: typing.Union[str, int]
+    :type proportional: typing.Union[int, str]
     :param proportional_edit_falloff: Proportional Editing Falloff, Falloff type for proportional editing mode * SMOOTH Smooth, Smooth falloff. * SPHERE Sphere, Spherical falloff. * ROOT Root, Root falloff. * INVERSE_SQUARE Inverse Square, Inverse Square falloff. * SHARP Sharp, Sharp falloff. * LINEAR Linear, Linear falloff. * CONSTANT Constant, Constant falloff. * RANDOM Random, Random falloff.
-    :type proportional_edit_falloff: typing.Union[str, int]
+    :type proportional_edit_falloff: typing.Union[int, str]
     :param proportional_size: Proportional Size
     :type proportional_size: float
     :param release_confirm: Confirm on Release, Always confirm operation when releasing button
@@ -1529,25 +1529,25 @@ def screw(steps: int = 9,
     pass
 
 
-def select_all(action: typing.Union[str, int] = 'TOGGLE'):
+def select_all(action: typing.Union[int, str] = 'TOGGLE'):
     ''' (De)select all vertices, edges or faces
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
 
 
-def select_axis(mode: typing.Union[str, int] = 'POSITIVE',
-                axis: typing.Union[str, int] = 'X_AXIS',
+def select_axis(mode: typing.Union[int, str] = 'POSITIVE',
+                axis: typing.Union[int, str] = 'X_AXIS',
                 threshold: float = 0.0001):
     ''' Select all data in the mesh on a single axis
 
     :param mode: Axis Mode, Axis side to use when selecting
-    :type mode: typing.Union[str, int]
+    :type mode: typing.Union[int, str]
     :param axis: Axis, Select the axis to compare each vertex on
-    :type axis: typing.Union[str, int]
+    :type axis: typing.Union[int, str]
     :param threshold: Threshold
     :type threshold: float
     '''
@@ -1556,14 +1556,14 @@ def select_axis(mode: typing.Union[str, int] = 'POSITIVE',
 
 
 def select_face_by_sides(number: int = 4,
-                         type: typing.Union[str, int] = 'EQUAL',
+                         type: typing.Union[int, str] = 'EQUAL',
                          extend: bool = True):
     ''' Select vertices or faces by the number of polygon sides
 
     :param number: Number of Vertices
     :type number: int
     :param type: Type, Type of comparison to make
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param extend: Extend, Extend the selection
     :type extend: bool
     '''
@@ -1590,11 +1590,11 @@ def select_less(use_face_step: bool = True):
 
 
 def select_linked(
-        delimit: typing.Union[typing.Set[str], typing.Set[int]] = {'SEAM'}):
+        delimit: typing.Union[typing.Set[int], typing.Set[str]] = {'SEAM'}):
     ''' Select all vertices connected to the current selection
 
     :param delimit: Delimit, Delimit selected region * NORMAL Normal, Delimit by face directions. * MATERIAL Material, Delimit by face material. * SEAM Seam, Delimit by edge seams. * SHARP Sharp, Delimit by sharp edges. * UV UVs, Delimit by UV coordinates.
-    :type delimit: typing.Union[typing.Set[str], typing.Set[int]]
+    :type delimit: typing.Union[typing.Set[int], typing.Set[str]]
     '''
 
     pass
@@ -1602,14 +1602,14 @@ def select_linked(
 
 def select_linked_pick(
         deselect: bool = False,
-        delimit: typing.Union[typing.Set[str], typing.Set[int]] = {'SEAM'},
+        delimit: typing.Union[typing.Set[int], typing.Set[str]] = {'SEAM'},
         index: int = -1):
     ''' (De)select all vertices linked to the edge under the mouse cursor
 
     :param deselect: Deselect
     :type deselect: bool
     :param delimit: Delimit, Delimit selected region * NORMAL Normal, Delimit by face directions. * MATERIAL Material, Delimit by face material. * SEAM Seam, Delimit by edge seams. * SHARP Sharp, Delimit by sharp edges. * UV UVs, Delimit by UV coordinates.
-    :type delimit: typing.Union[typing.Set[str], typing.Set[int]]
+    :type delimit: typing.Union[typing.Set[int], typing.Set[str]]
     :type index: int
     '''
 
@@ -1626,12 +1626,12 @@ def select_loose(extend: bool = False):
     pass
 
 
-def select_mirror(axis: typing.Union[typing.Set[str], typing.Set[int]] = {'X'},
+def select_mirror(axis: typing.Union[typing.Set[int], typing.Set[str]] = {'X'},
                   extend: bool = False):
     ''' Select mesh items at mirrored locations
 
     :param axis: Axis
-    :type axis: typing.Union[typing.Set[str], typing.Set[int]]
+    :type axis: typing.Union[typing.Set[int], typing.Set[str]]
     :param extend: Extend, Extend the existing selection
     :type extend: bool
     '''
@@ -1641,8 +1641,8 @@ def select_mirror(axis: typing.Union[typing.Set[str], typing.Set[int]] = {'X'},
 
 def select_mode(use_extend: bool = False,
                 use_expand: bool = False,
-                type: typing.Union[str, int] = 'VERT',
-                action: typing.Union[str, int] = 'TOGGLE'):
+                type: typing.Union[int, str] = 'VERT',
+                action: typing.Union[int, str] = 'TOGGLE'):
     ''' Change selection mode
 
     :param use_extend: Extend
@@ -1650,9 +1650,9 @@ def select_mode(use_extend: bool = False,
     :param use_expand: Expand
     :type use_expand: bool
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param action: Action, Selection action to execute * DISABLE Disable, Disable selected markers. * ENABLE Enable, Enable selected markers. * TOGGLE Toggle, Toggle disabled flag for selected markers.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -1725,7 +1725,7 @@ def select_prev_item():
 
 def select_random(percent: float = 50.0,
                   seed: int = 0,
-                  action: typing.Union[str, int] = 'SELECT'):
+                  action: typing.Union[int, str] = 'SELECT'):
     ''' Randomly select vertices
 
     :param percent: Percent, Percentage of objects to select randomly
@@ -1733,21 +1733,21 @@ def select_random(percent: float = 50.0,
     :param seed: Random Seed, Seed for the random number generator
     :type seed: int
     :param action: Action, Selection action to execute * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
 
 
-def select_similar(type: typing.Union[str, int] = 'NORMAL',
-                   compare: typing.Union[str, int] = 'EQUAL',
+def select_similar(type: typing.Union[int, str] = 'NORMAL',
+                   compare: typing.Union[int, str] = 'EQUAL',
                    threshold: float = 0.0):
     ''' Select similar vertices, edges or faces by property types
 
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param compare: Compare
-    :type compare: typing.Union[str, int]
+    :type compare: typing.Union[int, str]
     :param threshold: Threshold
     :type threshold: float
     '''
@@ -1773,11 +1773,11 @@ def select_ungrouped(extend: bool = False):
     pass
 
 
-def separate(type: typing.Union[str, int] = 'SELECTED'):
+def separate(type: typing.Union[int, str] = 'SELECTED'):
     ''' Separate selected geometry into a new mesh
 
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -1862,16 +1862,16 @@ def solidify(thickness: float = 0.01):
 
 
 def sort_elements(
-        type: typing.Union[str, int] = 'VIEW_ZAXIS',
-        elements: typing.Union[typing.Set[str], typing.Set[int]] = {'VERT'},
+        type: typing.Union[int, str] = 'VIEW_ZAXIS',
+        elements: typing.Union[typing.Set[int], typing.Set[str]] = {'VERT'},
         reverse: bool = False,
         seed: int = 0):
     ''' The order of selected vertices/edges/faces is modified, based on a given method
 
     :param type: Type, Type of re-ordering operation to apply * VIEW_ZAXIS View Z Axis, Sort selected elements from farthest to nearest one in current view. * VIEW_XAXIS View X Axis, Sort selected elements from left to right one in current view. * CURSOR_DISTANCE Cursor Distance, Sort selected elements from nearest to farthest from 3D cursor. * MATERIAL Material, Sort selected elements from smallest to greatest material index (faces only!). * SELECTED Selected, Move all selected elements in first places, preserving their relative order (WARNING: this will affect unselected elements' indices as well!). * RANDOMIZE Randomize, Randomize order of selected elements. * REVERSE Reverse, Reverse current order of selected elements.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param elements: Elements, Which elements to affect (vertices, edges and/or faces)
-    :type elements: typing.Union[typing.Set[str], typing.Set[int]]
+    :type elements: typing.Union[typing.Set[int], typing.Set[str]]
     :param reverse: Reverse, Reverse the sorting effect
     :type reverse: bool
     :param seed: Seed, Seed for random-based operations
@@ -1914,7 +1914,7 @@ def split():
 def subdivide(number_cuts: int = 1,
               smoothness: float = 0.0,
               quadtri: bool = False,
-              quadcorner: typing.Union[str, int] = 'STRAIGHT_CUT',
+              quadcorner: typing.Union[int, str] = 'STRAIGHT_CUT',
               fractal: float = 0.0,
               fractal_along_normal: float = 0.0,
               seed: int = 0):
@@ -1927,7 +1927,7 @@ def subdivide(number_cuts: int = 1,
     :param quadtri: Quad/Tri Mode, Tries to prevent ngons
     :type quadtri: bool
     :param quadcorner: Quad Corner Type, How to subdivide quad corners (anything other than Straight Cut will prevent ngons)
-    :type quadcorner: typing.Union[str, int]
+    :type quadcorner: typing.Union[int, str]
     :param fractal: Fractal, Fractal randomness factor
     :type fractal: float
     :param fractal_along_normal: Along Normal, Apply fractal displacement along normal only
@@ -1940,33 +1940,33 @@ def subdivide(number_cuts: int = 1,
 
 
 def subdivide_edgering(number_cuts: int = 10,
-                       interpolation: typing.Union[str, int] = 'PATH',
+                       interpolation: typing.Union[int, str] = 'PATH',
                        smoothness: float = 1.0,
                        profile_shape_factor: float = 0.0,
-                       profile_shape: typing.Union[str, int] = 'SMOOTH'):
+                       profile_shape: typing.Union[int, str] = 'SMOOTH'):
     ''' Undocumented
 
     :param number_cuts: Number of Cuts
     :type number_cuts: int
     :param interpolation: Interpolation, Interpolation method
-    :type interpolation: typing.Union[str, int]
+    :type interpolation: typing.Union[int, str]
     :param smoothness: Smoothness, Smoothness factor
     :type smoothness: float
     :param profile_shape_factor: Profile Factor, How much intermediary new edges are shrunk/expanded
     :type profile_shape_factor: float
     :param profile_shape: Profile Shape, Shape of the profile * SMOOTH Smooth, Smooth falloff. * SPHERE Sphere, Spherical falloff. * ROOT Root, Root falloff. * INVERSE_SQUARE Inverse Square, Inverse Square falloff. * SHARP Sharp, Sharp falloff. * LINEAR Linear, Linear falloff.
-    :type profile_shape: typing.Union[str, int]
+    :type profile_shape: typing.Union[int, str]
     '''
 
     pass
 
 
-def symmetrize(direction: typing.Union[str, int] = 'NEGATIVE_X',
+def symmetrize(direction: typing.Union[int, str] = 'NEGATIVE_X',
                threshold: float = 0.0001):
     ''' Enforce symmetry (both form and topological) across an axis
 
     :param direction: Direction, Which sides to copy from and to
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Union[int, str]
     :param threshold: Threshold
     :type threshold: float
     '''
@@ -1974,14 +1974,14 @@ def symmetrize(direction: typing.Union[str, int] = 'NEGATIVE_X',
     pass
 
 
-def symmetry_snap(direction: typing.Union[str, int] = 'NEGATIVE_X',
+def symmetry_snap(direction: typing.Union[int, str] = 'NEGATIVE_X',
                   threshold: float = 0.05,
                   factor: float = 0.5,
                   use_center: bool = True):
     ''' Snap vertex pairs to their mirrored locations
 
     :param direction: Direction, Which sides to copy from and to
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Union[int, str]
     :param threshold: Threshold
     :type threshold: float
     :param factor: Factor
