@@ -3,15 +3,17 @@ import typing
 import bpy.types
 
 
-def add_and_link_node(settings: typing.Union[
-        typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection'] = None,
-                      use_transform: bool = False,
-                      type: str = "",
-                      link_socket_index: int = 0):
+def add_and_link_node(
+        settings: typing.
+        Union[typing.Dict[str, 'bpy.types.NodeSetting'], typing.
+              List['bpy.types.NodeSetting'], 'bpy_prop_collection'] = None,
+        use_transform: bool = False,
+        type: str = "",
+        link_socket_index: int = 0):
     ''' Add a node to the active tree and link to an existing socket
 
     :param settings: Settings, Settings to be applied on the newly created node
-    :type settings: typing.Union[typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
+    :type settings: typing.Union[typing.Dict[str, 'bpy.types.NodeSetting'], typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
     :param use_transform: Use Transform, Start transform operator after inserting the node
     :type use_transform: bool
     :param type: Node Type, Node type
@@ -41,8 +43,8 @@ def add_file(filepath: str = "",
              relative_path: bool = True,
              show_multiview: bool = False,
              use_multiview: bool = False,
-             display_type: typing.Union[str, int] = 'DEFAULT',
-             sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
+             display_type: typing.Union[int, str] = 'DEFAULT',
+             sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
              name: str = "Image"):
     ''' Add a file node to the current node editor
 
@@ -83,9 +85,9 @@ def add_file(filepath: str = "",
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     :param name: Name, Data-block name to assign
     :type name: str
     '''
@@ -103,14 +105,16 @@ def add_mask(name: str = "Mask"):
     pass
 
 
-def add_node(settings: typing.Union[typing.List['bpy.types.NodeSetting'],
-                                    'bpy_prop_collection'] = None,
-             use_transform: bool = False,
-             type: str = ""):
+def add_node(
+        settings: typing.
+        Union[typing.Dict[str, 'bpy.types.NodeSetting'], typing.
+              List['bpy.types.NodeSetting'], 'bpy_prop_collection'] = None,
+        use_transform: bool = False,
+        type: str = ""):
     ''' Add a node to the active tree
 
     :param settings: Settings, Settings to be applied on the newly created node
-    :type settings: typing.Union[typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
+    :type settings: typing.Union[typing.Dict[str, 'bpy.types.NodeSetting'], typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
     :param use_transform: Use Transform, Start transform operator after inserting the node
     :type use_transform: bool
     :param type: Node Type, Node type
@@ -120,13 +124,14 @@ def add_node(settings: typing.Union[typing.List['bpy.types.NodeSetting'],
     pass
 
 
-def add_reroute(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                                   'bpy_prop_collection'] = None,
+def add_reroute(path: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
                 cursor: int = 6):
     ''' Add a reroute node
 
     :param path: path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param cursor: Cursor
     :type cursor: int
     '''
@@ -134,21 +139,23 @@ def add_reroute(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
     pass
 
 
-def add_search(settings: typing.Union[typing.List['bpy.types.NodeSetting'],
-                                      'bpy_prop_collection'] = None,
-               use_transform: bool = False,
-               type: str = "",
-               node_item: typing.Union[str, int] = ''):
+def add_search(
+        settings: typing.
+        Union[typing.Dict[str, 'bpy.types.NodeSetting'], typing.
+              List['bpy.types.NodeSetting'], 'bpy_prop_collection'] = None,
+        use_transform: bool = False,
+        type: str = "",
+        node_item: typing.Union[int, str] = ''):
     ''' Add a node to the active tree
 
     :param settings: Settings, Settings to be applied on the newly created node
-    :type settings: typing.Union[typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
+    :type settings: typing.Union[typing.Dict[str, 'bpy.types.NodeSetting'], typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
     :param use_transform: Use Transform, Start transform operator after inserting the node
     :type use_transform: bool
     :param type: Node Type, Node type
     :type type: str
     :param node_item: Node Type, Node type
-    :type node_item: typing.Union[str, int]
+    :type node_item: typing.Union[int, str]
     '''
 
     pass
@@ -332,11 +339,11 @@ def group_make():
     pass
 
 
-def group_separate(type: typing.Union[str, int] = 'COPY'):
+def group_separate(type: typing.Union[int, str] = 'COPY'):
     ''' Separate selected nodes from the node group
 
     :param type: Type * COPY Copy, Copy to parent node tree, keep group intact. * MOVE Move, Move to parent node tree, remove from group.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -410,13 +417,14 @@ def link_viewer():
     pass
 
 
-def links_cut(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                                 'bpy_prop_collection'] = None,
+def links_cut(path: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
               cursor: int = 9):
     ''' Use the mouse to cut (remove) some links
 
     :param path: path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param cursor: Cursor
     :type cursor: int
     '''
@@ -464,11 +472,11 @@ def mute_toggle():
     pass
 
 
-def new_node_tree(type: typing.Union[str, int] = '', name: str = "NodeTree"):
+def new_node_tree(type: typing.Union[int, str] = '', name: str = "NodeTree"):
     ''' Create a new node tree
 
     :param type: Tree Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param name: Name
     :type name: str
     '''
@@ -514,11 +522,11 @@ def output_file_add_socket(file_path: str = "Image"):
     pass
 
 
-def output_file_move_active_socket(direction: typing.Union[str, int] = 'DOWN'):
+def output_file_move_active_socket(direction: typing.Union[int, str] = 'DOWN'):
     ''' Move the active input of a file output node up or down the list
 
     :param direction: Direction
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Union[int, str]
     '''
 
     pass
@@ -602,11 +610,11 @@ def select(mouse_x: int = 0, mouse_y: int = 0, extend: bool = False):
     pass
 
 
-def select_all(action: typing.Union[str, int] = 'TOGGLE'):
+def select_all(action: typing.Union[int, str] = 'TOGGLE'):
     ''' (De)select all nodes
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -660,26 +668,27 @@ def select_circle(x: int = 0,
 
 
 def select_grouped(extend: bool = False,
-                   type: typing.Union[str, int] = 'TYPE'):
+                   type: typing.Union[int, str] = 'TYPE'):
     ''' Select nodes with similar properties
 
     :param extend: Extend, Extend selection instead of deselecting everything first
     :type extend: bool
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
-def select_lasso(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                                    'bpy_prop_collection'] = None,
+def select_lasso(path: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
                  deselect: bool = False,
                  extend: bool = True):
     ''' Select nodes using lasso selection
 
     :param path: Path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param deselect: Deselect, Deselect rather than select items
     :type deselect: bool
     :param extend: Extend, Extend selection instead of deselecting everything first
@@ -783,21 +792,21 @@ def tree_path_parent():
     pass
 
 
-def tree_socket_add(in_out: typing.Union[str, int] = 'IN'):
+def tree_socket_add(in_out: typing.Union[int, str] = 'IN'):
     ''' Add an input or output socket to the current node tree
 
     :param in_out: Socket Type
-    :type in_out: typing.Union[str, int]
+    :type in_out: typing.Union[int, str]
     '''
 
     pass
 
 
-def tree_socket_move(direction: typing.Union[str, int] = 'UP'):
+def tree_socket_move(direction: typing.Union[int, str] = 'UP'):
     ''' Move a socket up or down in the current node tree's sockets stack
 
     :param direction: Direction
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Union[int, str]
     '''
 
     pass
