@@ -2,41 +2,41 @@ import sys
 import typing
 
 
-def action_set(action: typing.Union[str, int] = ''):
+def action_set(action: typing.Union[int, str] = ''):
     ''' Change the active action used
 
     :param action: Action
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
 
 
-def animdata_operation(type: typing.Union[str, int] = 'CLEAR_ANIMDATA'):
+def animdata_operation(type: typing.Union[int, str] = 'CLEAR_ANIMDATA'):
     ''' Undocumented
 
     :param type: Animation Operation * CLEAR_ANIMDATA Clear Animation Data, Remove this animation data container. * SET_ACT Set Action. * CLEAR_ACT Unlink Action. * REFRESH_DRIVERS Refresh Drivers. * CLEAR_DRIVERS Clear Drivers.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
-def constraint_operation(type: typing.Union[str, int] = 'ENABLE'):
+def constraint_operation(type: typing.Union[int, str] = 'ENABLE'):
     ''' Undocumented
 
     :param type: Constraint Operation
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
-def data_operation(type: typing.Union[str, int] = 'SELECT'):
+def data_operation(type: typing.Union[int, str] = 'SELECT'):
     ''' Undocumented
 
     :param type: Data Operation
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -76,11 +76,11 @@ def group_link(object: str = "Object"):
     pass
 
 
-def group_operation(type: typing.Union[str, int] = 'UNLINK'):
+def group_operation(type: typing.Union[int, str] = 'UNLINK'):
     ''' Undocumented
 
     :param type: Group Operation * UNLINK Unlink Group. * LOCAL Make Local Group. * LINK Link Group Objects to Scene. * DELETE Delete Group. * REMAP Remap Users, Make all users of selected data-blocks to use instead current (clicked) one. * INSTANCE Instance Groups in Scene. * TOGVIS Toggle Visible Group. * TOGSEL Toggle Selectable. * TOGREN Toggle Renderable. * RENAME Rename.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -94,27 +94,27 @@ def id_delete():
     pass
 
 
-def id_operation(type: typing.Union[str, int] = 'UNLINK'):
+def id_operation(type: typing.Union[int, str] = 'UNLINK'):
     ''' Undocumented
 
     :param type: ID data Operation * UNLINK Unlink. * LOCAL Make Local. * SINGLE Make Single User. * DELETE Delete, WARNING: no undo. * REMAP Remap Users, Make all users of selected data-blocks to use instead current (clicked) one. * ADD_FAKE Add Fake User, Ensure data-block gets saved even if it isn't in use (e.g. for motion and material libraries). * CLEAR_FAKE Clear Fake User. * RENAME Rename. * SELECT_LINKED Select Linked.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
-def id_remap(id_type: typing.Union[str, int] = 'OBJECT',
-             old_id: typing.Union[str, int] = '',
-             new_id: typing.Union[str, int] = ''):
+def id_remap(id_type: typing.Union[int, str] = 'OBJECT',
+             old_id: typing.Union[int, str] = '',
+             new_id: typing.Union[int, str] = ''):
     ''' Undocumented
 
     :param id_type: ID Type
-    :type id_type: typing.Union[str, int]
+    :type id_type: typing.Union[int, str]
     :param old_id: Old ID, Old ID to replace
-    :type old_id: typing.Union[str, int]
+    :type old_id: typing.Union[int, str]
     :param new_id: New ID, New ID to remap all selected IDs' users to
-    :type new_id: typing.Union[str, int]
+    :type new_id: typing.Union[int, str]
     '''
 
     pass
@@ -166,11 +166,11 @@ def keyingset_remove_selected():
     pass
 
 
-def lib_operation(type: typing.Union[str, int] = 'RENAME'):
+def lib_operation(type: typing.Union[int, str] = 'RENAME'):
     ''' Undocumented
 
     :param type: Library Operation * RENAME Rename. * DELETE Delete, Delete this library and all its item from Blender - WARNING: no undo. * RELOCATE Relocate, Select a new path for this library, and reload all its data. * RELOAD Reload, Reload all data from this library.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -196,21 +196,21 @@ def material_drop(object: str = "Object", material: str = "Material"):
     pass
 
 
-def modifier_operation(type: typing.Union[str, int] = 'TOGVIS'):
+def modifier_operation(type: typing.Union[int, str] = 'TOGVIS'):
     ''' Undocumented
 
     :param type: Modifier Operation
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
-def object_operation(type: typing.Union[str, int] = 'SELECT'):
+def object_operation(type: typing.Union[int, str] = 'SELECT'):
     ''' Undocumented
 
     :param type: Object Operation * SELECT Select. * DESELECT Deselect. * SELECT_HIERARCHY Select Hierarchy. * DELETE Delete. * DELETE_HIERARCHY Delete Hierarchy. * REMAP Remap Users, Make all users of selected data-blocks to use instead a new chosen one. * TOGVIS Toggle Visible. * TOGSEL Toggle Selectable. * TOGREN Toggle Renderable. * RENAME Rename.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -233,13 +233,13 @@ def orphans_purge():
 
 
 def parent_clear(dragged_obj: str = "Object",
-                 type: typing.Union[str, int] = 'CLEAR'):
+                 type: typing.Union[int, str] = 'CLEAR'):
     ''' Drag to clear parent in Outliner
 
     :param dragged_obj: Child, Child Object
     :type dragged_obj: str
     :param type: Type * CLEAR Clear Parent, Completely clear the parenting relationship, including involved modifiers if any. * CLEAR_KEEP_TRANSFORM Clear and Keep Transformation, As 'Clear Parent', but keep the current visual transformations of the object. * CLEAR_INVERSE Clear Parent Inverse, Reset the transform corrections applied to the parenting relationship, does not remove parenting itself.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -247,7 +247,7 @@ def parent_clear(dragged_obj: str = "Object",
 
 def parent_drop(child: str = "Object",
                 parent: str = "Object",
-                type: typing.Union[str, int] = 'OBJECT'):
+                type: typing.Union[int, str] = 'OBJECT'):
     ''' Drag to parent in Outliner
 
     :param child: Child, Child Object
@@ -255,7 +255,7 @@ def parent_drop(child: str = "Object",
     :param parent: Parent, Parent Object
     :type parent: str
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -281,11 +281,11 @@ def scene_drop(object: str = "Object", scene: str = "Scene"):
     pass
 
 
-def scene_operation(type: typing.Union[str, int] = 'DELETE'):
+def scene_operation(type: typing.Union[int, str] = 'DELETE'):
     ''' Context menu for scene operations
 
     :param type: Scene Operation
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
