@@ -46,7 +46,7 @@ def opengl(animation: bool = False,
 
 
 def play_rendered_anim():
-    ''' Play back rendered frames/movies using an external player
+    ''' Play back rendered frames/movies using an external player :file: startup/bl_operators/screen_play_rendered_anim.py\:76 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/screen_play_rendered_anim.py$76> _
 
     '''
 
@@ -87,11 +87,11 @@ def render(animation: bool = False,
     pass
 
 
-def shutter_curve_preset(shape: typing.Union[str, int] = 'SMOOTH'):
+def shutter_curve_preset(shape: typing.Union[int, str] = 'SMOOTH'):
     ''' Set shutter curve
 
     :param shape: Mode
-    :type shape: typing.Union[str, int]
+    :type shape: typing.Union[int, str]
     '''
 
     pass
