@@ -91,14 +91,14 @@ def area_options():
     pass
 
 
-def area_split(direction: typing.Union[str, int] = 'HORIZONTAL',
+def area_split(direction: typing.Union[int, str] = 'HORIZONTAL',
                factor: float = 0.5,
                mouse_x: int = -100,
                mouse_y: int = -100):
     ''' Split selected area into new windows
 
     :param direction: Direction
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Union[int, str]
     :param factor: Factor
     :type factor: float
     :param mouse_x: Mouse X
@@ -322,8 +322,8 @@ def screenshot(filepath: str = "",
                filemode: int = 9,
                show_multiview: bool = False,
                use_multiview: bool = False,
-               display_type: typing.Union[str, int] = 'DEFAULT',
-               sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
+               display_type: typing.Union[int, str] = 'DEFAULT',
+               sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
                full: bool = True):
     ''' Capture a picture of the active area or whole Blender window
 
@@ -364,9 +364,9 @@ def screenshot(filepath: str = "",
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     :param full: Full Screen, Capture the whole window (otherwise only capture the active area)
     :type full: bool
     '''
@@ -374,6 +374,16 @@ def screenshot(filepath: str = "",
     pass
 
 
+def space_context_cycle(direction: typing.Union[int, str] = 'NEXT'):
+    ''' Cycle through the editor context by activating the next/previous one
+
+    :param direction: Direction, Direction to cycle through
+    :type direction: typing.Union[int, str]
+    '''
+
+    pass
+
+
 def spacedata_cleanup():
     ''' Remove unused settings for invisible editors
 
