@@ -38,8 +38,8 @@ def envmap_save(layout: typing.List[float] = (0.0, 0.0, 1.0, 0.0, 2.0, 0.0,
                 filemode: int = 9,
                 show_multiview: bool = False,
                 use_multiview: bool = False,
-                display_type: typing.Union[str, int] = 'DEFAULT',
-                sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
+                display_type: typing.Union[int, str] = 'DEFAULT',
+                sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
     ''' Save the current generated Environment map to an image file
 
     :param layout: File layout, Flat array describing the X,Y position of each cube face in the output image, where 1 is the size of a face - order is [+Z -Z +Y -X -Y +X] (use -1 to skip a face)
@@ -81,9 +81,9 @@ def envmap_save(layout: typing.List[float] = (0.0, 0.0, 1.0, 0.0, 2.0, 0.0,
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
@@ -105,11 +105,11 @@ def slot_copy():
     pass
 
 
-def slot_move(type: typing.Union[str, int] = 'UP'):
+def slot_move(type: typing.Union[int, str] = 'UP'):
     ''' Move texture slots up and down
 
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
