@@ -2,9 +2,11 @@ import sys
 import typing
 
 
-def copy_data_path_button():
+def copy_data_path_button(full_path: bool = False):
     ''' Copy the RNA data path for this property to the clipboard
 
+    :param full_path: full_path, Copy full data path
+    :type full_path: bool
     '''
 
     pass
@@ -84,7 +86,7 @@ def eyedropper_driver(mapping_type: typing.Union[int, str] = 'SINGLE_MANY'):
 
 
 def eyedropper_id():
-    ''' Sample a datablock from the 3D View to store in a property
+    ''' Sample a data-block from the 3D View to store in a property
 
     '''
 
