@@ -23,8 +23,8 @@ def background_image_add(
         relative_path: bool = True,
         show_multiview: bool = False,
         use_multiview: bool = False,
-        display_type: typing.Union[str, int] = 'DEFAULT',
-        sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
+        display_type: typing.Union[int, str] = 'DEFAULT',
+        sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
     ''' Add a new background image (Ctrl for Empty Object)
 
     :param name: Name, Image name to assign
@@ -66,9 +66,9 @@ def background_image_add(
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
@@ -233,7 +233,7 @@ def localview():
 
 
 def manipulator(constraint_axis: typing.List[bool] = (False, False, False),
-                constraint_orientation: typing.Union[str, int] = 'GLOBAL',
+                constraint_orientation: typing.Union[int, str] = 'GLOBAL',
                 release_confirm: bool = False,
                 use_accurate: bool = False,
                 use_planar_constraint: bool = False):
@@ -242,7 +242,7 @@ def manipulator(constraint_axis: typing.List[bool] = (False, False, False),
     :param constraint_axis: Constraint Axis
     :type constraint_axis: typing.List[bool]
     :param constraint_orientation: Orientation, Transformation orientation
-    :type constraint_orientation: typing.Union[str, int]
+    :type constraint_orientation: typing.Union[int, str]
     :param release_confirm: Confirm on Release, Always confirm operation when releasing button
     :type release_confirm: bool
     :param use_accurate: Accurate, Use accurate transformation
@@ -440,14 +440,15 @@ def select_circle(x: int = 0,
     pass
 
 
-def select_lasso(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                                    'bpy_prop_collection'] = None,
+def select_lasso(path: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
                  deselect: bool = False,
                  extend: bool = True):
     ''' Select items using lasso selection
 
     :param path: Path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param deselect: Deselect, Deselect rather than select items
     :type deselect: bool
     :param extend: Extend, Extend selection instead of deselecting everything first
@@ -457,11 +458,11 @@ def select_lasso(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
     pass
 
 
-def select_menu(name: typing.Union[str, int] = '', toggle: bool = False):
+def select_menu(name: typing.Union[int, str] = '', toggle: bool = False):
     ''' Menu object selection
 
     :param name: Object Name
-    :type name: typing.Union[str, int]
+    :type name: typing.Union[int, str]
     :param toggle: Toggle, Toggle selection instead of deselecting everything first
     :type toggle: bool
     '''
@@ -636,23 +637,23 @@ def view_lock_to_active():
     pass
 
 
-def view_orbit(angle: float = 0.0, type: typing.Union[str, int] = 'ORBITLEFT'):
+def view_orbit(angle: float = 0.0, type: typing.Union[int, str] = 'ORBITLEFT'):
     ''' Orbit the view
 
     :param angle: Roll
     :type angle: float
     :param type: Orbit, Direction of View Orbit * ORBITLEFT Orbit Left, Orbit the view around to the Left. * ORBITRIGHT Orbit Right, Orbit the view around to the Right. * ORBITUP Orbit Up, Orbit the view Up. * ORBITDOWN Orbit Down, Orbit the view Down.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
-def view_pan(type: typing.Union[str, int] = 'PANLEFT'):
+def view_pan(type: typing.Union[int, str] = 'PANLEFT'):
     ''' Pan the view
 
     :param type: Pan, Direction of View Pan * PANLEFT Pan Left, Pan the view to the Left. * PANRIGHT Pan Right, Pan the view to the Right. * PANUP Pan Up, Pan the view Up. * PANDOWN Pan Down, Pan the view Down.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -666,13 +667,13 @@ def view_persportho():
     pass
 
 
-def view_roll(angle: float = 0.0, type: typing.Union[str, int] = 'ANGLE'):
+def view_roll(angle: float = 0.0, type: typing.Union[int, str] = 'ANGLE'):
     ''' Roll the view
 
     :param angle: Roll
     :type angle: float
     :param type: Roll Angle Source, How roll angle is calculated * ANGLE Roll Angle, Roll the view using an angle value. * LEFT Roll Left, Roll the view around to the Left. * RIGHT Roll Right, Roll the view around to the Right.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -688,12 +689,12 @@ def view_selected(use_all_regions: bool = False):
     pass
 
 
-def viewnumpad(type: typing.Union[str, int] = 'LEFT',
+def viewnumpad(type: typing.Union[int, str] = 'LEFT',
                align_active: bool = False):
     ''' Use a preset viewpoint
 
     :param type: View, Preset viewpoint to use * LEFT Left, View From the Left. * RIGHT Right, View From the Right. * BOTTOM Bottom, View From the Bottom. * TOP Top, View From the Top. * FRONT Front, View From the Front. * BACK Back, View From the Back. * CAMERA Camera, View From the Active Camera.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param align_active: Align Active, Align to the active object's axis
     :type align_active: bool
     '''
