@@ -34,7 +34,7 @@ def addon_expand(module: str = ""):
 
 
 def addon_install(overwrite: bool = True,
-                  target: typing.Union[str, int] = 'DEFAULT',
+                  target: typing.Union[int, str] = 'DEFAULT',
                   filepath: str = "",
                   filter_folder: bool = True,
                   filter_python: bool = True,
@@ -44,7 +44,7 @@ def addon_install(overwrite: bool = True,
     :param overwrite: Overwrite, Remove existing add-ons with the same ID
     :type overwrite: bool
     :param target: Target Path
-    :type target: typing.Union[str, int]
+    :type target: typing.Union[int, str]
     :param filepath: filepath
     :type filepath: str
     :param filter_folder: Filter folders
@@ -102,8 +102,8 @@ def alembic_export(filepath: str = "",
                    filter_folder: bool = True,
                    filter_blenlib: bool = False,
                    filemode: int = 8,
-                   display_type: typing.Union[str, int] = 'DEFAULT',
-                   sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
+                   display_type: typing.Union[int, str] = 'DEFAULT',
+                   sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
                    start: int = -2147483648,
                    end: int = -2147483648,
                    xsamples: int = 1,
@@ -121,11 +121,11 @@ def alembic_export(filepath: str = "",
                    face_sets: bool = False,
                    subdiv_schema: bool = False,
                    apply_subdiv: bool = False,
-                   compression_type: typing.Union[str, int] = 'OGAWA',
+                   compression_type: typing.Union[int, str] = 'OGAWA',
                    global_scale: float = 1.0,
                    triangulate: bool = False,
-                   quad_method: typing.Union[str, int] = 'SHORTEST_DIAGONAL',
-                   ngon_method: typing.Union[str, int] = 'BEAUTY',
+                   quad_method: typing.Union[int, str] = 'SHORTEST_DIAGONAL',
+                   ngon_method: typing.Union[int, str] = 'BEAUTY',
                    export_hair: bool = True,
                    export_particles: bool = True,
                    as_background_job: bool = True,
@@ -165,9 +165,9 @@ def alembic_export(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     :param start: Start Frame, Start frame of the export, use the default value to take the start frame of the current scene
     :type start: int
     :param end: End Frame, End frame of the export, use the default value to take the end frame of the current scene
@@ -203,15 +203,15 @@ def alembic_export(filepath: str = "",
     :param apply_subdiv: Apply Subsurf, Export subdivision surfaces as meshes
     :type apply_subdiv: bool
     :param compression_type: Compression
-    :type compression_type: typing.Union[str, int]
+    :type compression_type: typing.Union[int, str]
     :param global_scale: Scale, Value by which to enlarge or shrink the objects with respect to the world's origin
     :type global_scale: float
     :param triangulate: Triangulate, Export Polygons (Quads & NGons) as Triangles
     :type triangulate: bool
     :param quad_method: Quad Method, Method for splitting the quads into triangles * BEAUTY Beauty , Split the quads in nice triangles, slower method. * FIXED Fixed, Split the quads on the first and third vertices. * FIXED_ALTERNATE Fixed Alternate, Split the quads on the 2nd and 4th vertices. * SHORTEST_DIAGONAL Shortest Diagonal, Split the quads based on the distance between the vertices.
-    :type quad_method: typing.Union[str, int]
+    :type quad_method: typing.Union[int, str]
     :param ngon_method: Polygon Method, Method for splitting the polygons into triangles * BEAUTY Beauty , Split the quads in nice triangles, slower method. * FIXED Fixed, Split the quads on the first and third vertices. * FIXED_ALTERNATE Fixed Alternate, Split the quads on the 2nd and 4th vertices. * SHORTEST_DIAGONAL Shortest Diagonal, Split the quads based on the distance between the vertices.
-    :type ngon_method: typing.Union[str, int]
+    :type ngon_method: typing.Union[int, str]
     :param export_hair: Export Hair, Exports hair particle systems as animated curves
     :type export_hair: bool
     :param export_particles: Export Particles, Exports non-hair particle systems
@@ -240,8 +240,8 @@ def alembic_import(filepath: str = "",
                    filter_folder: bool = True,
                    filter_blenlib: bool = False,
                    filemode: int = 8,
-                   display_type: typing.Union[str, int] = 'DEFAULT',
-                   sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
+                   display_type: typing.Union[int, str] = 'DEFAULT',
+                   sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
                    scale: float = 1.0,
                    set_frame_range: bool = True,
                    validate_meshes: bool = False,
@@ -282,9 +282,9 @@ def alembic_import(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     :param scale: Scale, Value by which to enlarge or shrink the objects with respect to the world's origin
     :type scale: float
     :param set_frame_range: Set Frame Range, If checked, update scene's start and end frame to match those of the Alembic archive
@@ -337,34 +337,35 @@ def appconfig_default():
     pass
 
 
-def append(
-        filepath: str = "",
-        directory: str = "",
-        filename: str = "",
-        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                            'bpy_prop_collection'] = None,
-        filter_blender: bool = True,
-        filter_backup: bool = False,
-        filter_image: bool = False,
-        filter_movie: bool = False,
-        filter_python: bool = False,
-        filter_font: bool = False,
-        filter_sound: bool = False,
-        filter_text: bool = False,
-        filter_btx: bool = False,
-        filter_collada: bool = False,
-        filter_alembic: bool = False,
-        filter_folder: bool = True,
-        filter_blenlib: bool = True,
-        filemode: int = 1,
-        display_type: typing.Union[str, int] = 'DEFAULT',
-        sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
-        link: bool = False,
-        autoselect: bool = True,
-        active_layer: bool = True,
-        instance_groups: bool = False,
-        set_fake: bool = False,
-        use_recursive: bool = True):
+def append(filepath: str = "",
+           directory: str = "",
+           filename: str = "",
+           files: typing.
+           Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+                 List['bpy.types.OperatorFileListElement'],
+                 'bpy_prop_collection'] = None,
+           filter_blender: bool = True,
+           filter_backup: bool = False,
+           filter_image: bool = False,
+           filter_movie: bool = False,
+           filter_python: bool = False,
+           filter_font: bool = False,
+           filter_sound: bool = False,
+           filter_text: bool = False,
+           filter_btx: bool = False,
+           filter_collada: bool = False,
+           filter_alembic: bool = False,
+           filter_folder: bool = True,
+           filter_blenlib: bool = True,
+           filemode: int = 1,
+           display_type: typing.Union[int, str] = 'DEFAULT',
+           sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
+           link: bool = False,
+           autoselect: bool = True,
+           active_layer: bool = True,
+           instance_groups: bool = False,
+           set_fake: bool = False,
+           use_recursive: bool = True):
     ''' Append from a Library .blend file
 
     :param filepath: File Path, Path to file
@@ -374,7 +375,7 @@ def append(
     :param filename: File Name, Name of the file
     :type filename: str
     :param files: Files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -404,9 +405,9 @@ def append(
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     :param link: Link, Link the objects or data-blocks rather than appending
     :type link: bool
     :param autoselect: Select, Select new objects
@@ -469,11 +470,11 @@ def collada_export(
         filter_folder: bool = True,
         filter_blenlib: bool = False,
         filemode: int = 8,
-        display_type: typing.Union[str, int] = 'DEFAULT',
-        sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
+        display_type: typing.Union[int, str] = 'DEFAULT',
+        sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
         apply_modifiers: bool = False,
         export_mesh_type: int = 0,
-        export_mesh_type_selection: typing.Union[str, int] = 'view',
+        export_mesh_type_selection: typing.Union[int, str] = 'view',
         selected: bool = False,
         include_children: bool = False,
         include_armatures: bool = False,
@@ -487,9 +488,9 @@ def collada_export(
         sort_by_name: bool = False,
         export_transformation_type: int = 0,
         export_transformation_type_selection: typing.
-        Union[str, int] = 'matrix',
+        Union[int, str] = 'matrix',
         export_texture_type: int = 0,
-        export_texture_type_selection: typing.Union[str, int] = 'mat',
+        export_texture_type_selection: typing.Union[int, str] = 'mat',
         open_sim: bool = False,
         limit_precision: bool = False,
         keep_bind_info: bool = False):
@@ -528,15 +529,15 @@ def collada_export(
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     :param apply_modifiers: Apply Modifiers, Apply modifiers to exported mesh (non destructive))
     :type apply_modifiers: bool
     :param export_mesh_type: Resolution, Modifier resolution for export
     :type export_mesh_type: int
     :param export_mesh_type_selection: Resolution, Modifier resolution for export * view View, Apply modifier's view settings. * render Render, Apply modifier's render settings.
-    :type export_mesh_type_selection: typing.Union[str, int]
+    :type export_mesh_type_selection: typing.Union[int, str]
     :param selected: Selection Only, Export only selected elements
     :type selected: bool
     :param include_children: Include Children, Export all children of selected objects (even if not selected)
@@ -562,11 +563,11 @@ def collada_export(
     :param export_transformation_type: Transform, Transformation type for translation, scale and rotation
     :type export_transformation_type: int
     :param export_transformation_type_selection: Transform, Transformation type for translation, scale and rotation * matrix Matrix, Use <matrix> to specify transformations. * transrotloc TransRotLoc, Use <translate>, <rotate>, <scale> to specify transformations.
-    :type export_transformation_type_selection: typing.Union[str, int]
+    :type export_transformation_type_selection: typing.Union[int, str]
     :param export_texture_type: Texture Type, Type for exported Textures (UV or MAT)
     :type export_texture_type: int
     :param export_texture_type_selection: Texture Type, Type for exported Textures (UV or MAT) * mat Materials, Export Materials. * uv UV Textures, Export UV Textures (Face textures) as materials.
-    :type export_texture_type_selection: typing.Union[str, int]
+    :type export_texture_type_selection: typing.Union[int, str]
     :param open_sim: Export to SL/OpenSim, Compatibility mode for SL, OpenSim and other compatible online worlds
     :type open_sim: bool
     :param limit_precision: Limit Precision, Reduce the precision of the exported data to 6 digits
@@ -593,8 +594,8 @@ def collada_import(filepath: str = "",
                    filter_folder: bool = True,
                    filter_blenlib: bool = False,
                    filemode: int = 8,
-                   display_type: typing.Union[str, int] = 'DEFAULT',
-                   sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
+                   display_type: typing.Union[int, str] = 'DEFAULT',
+                   sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
                    import_units: bool = False,
                    fix_orientation: bool = False,
                    find_chains: bool = False,
@@ -634,9 +635,9 @@ def collada_import(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     :param import_units: Import Units, If disabled match import to Blender's current Unit settings, otherwise use the settings from the Imported scene
     :type import_units: bool
     :param fix_orientation: Fix Leaf Bones, Fix Orientation of Leaf Bones (Collada does only support Joints)
@@ -656,7 +657,7 @@ def collada_import(filepath: str = "",
 
 def context_collection_boolean_set(data_path_iter: str = "",
                                    data_path_item: str = "",
-                                   type: typing.Union[str, int] = 'TOGGLE'):
+                                   type: typing.Union[int, str] = 'TOGGLE'):
     ''' Set boolean values for a collection of items
 
     :param data_path_iter: data_path_iter, The data path relative to the context, must point to an iterable
@@ -664,7 +665,7 @@ def context_collection_boolean_set(data_path_iter: str = "",
     :param data_path_item: data_path_item, The data path from each iterable to the value (int or float)
     :type data_path_item: str
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -1119,8 +1120,8 @@ def lib_reload(library: str = "",
                filter_blenlib: bool = False,
                filemode: int = 8,
                relative_path: bool = True,
-               display_type: typing.Union[str, int] = 'DEFAULT',
-               sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
+               display_type: typing.Union[int, str] = 'DEFAULT',
+               sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
     ''' Reload the given library
 
     :param library: Library, Library to reload
@@ -1162,9 +1163,9 @@ def lib_reload(library: str = "",
     :param relative_path: Relative Path, Select the file relative to the blend file
     :type relative_path: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
@@ -1175,8 +1176,10 @@ def lib_relocate(
         filepath: str = "",
         directory: str = "",
         filename: str = "",
-        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                            'bpy_prop_collection'] = None,
+        files: typing.
+        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+              List['bpy.types.OperatorFileListElement'],
+              'bpy_prop_collection'] = None,
         filter_blender: bool = True,
         filter_backup: bool = False,
         filter_image: bool = False,
@@ -1192,8 +1195,8 @@ def lib_relocate(
         filter_blenlib: bool = False,
         filemode: int = 8,
         relative_path: bool = True,
-        display_type: typing.Union[str, int] = 'DEFAULT',
-        sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
+        display_type: typing.Union[int, str] = 'DEFAULT',
+        sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
     ''' Relocate the given library to one or several others
 
     :param library: Library, Library to relocate
@@ -1205,7 +1208,7 @@ def lib_relocate(
     :param filename: File Name, Name of the file
     :type filename: str
     :param files: Files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -1237,9 +1240,9 @@ def lib_relocate(
     :param relative_path: Relative Path, Select the file relative to the blend file
     :type relative_path: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
@@ -1248,8 +1251,10 @@ def lib_relocate(
 def link(filepath: str = "",
          directory: str = "",
          filename: str = "",
-         files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                             'bpy_prop_collection'] = None,
+         files: typing.
+         Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+               List['bpy.types.OperatorFileListElement'],
+               'bpy_prop_collection'] = None,
          filter_blender: bool = True,
          filter_backup: bool = False,
          filter_image: bool = False,
@@ -1265,8 +1270,8 @@ def link(filepath: str = "",
          filter_blenlib: bool = True,
          filemode: int = 1,
          relative_path: bool = True,
-         display_type: typing.Union[str, int] = 'DEFAULT',
-         sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
+         display_type: typing.Union[int, str] = 'DEFAULT',
+         sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
          link: bool = True,
          autoselect: bool = True,
          active_layer: bool = True,
@@ -1280,7 +1285,7 @@ def link(filepath: str = "",
     :param filename: File Name, Name of the file
     :type filename: str
     :param files: Files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -1312,9 +1317,9 @@ def link(filepath: str = "",
     :param relative_path: Relative Path, Select the file relative to the blend file
     :type relative_path: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     :param link: Link, Link the objects or data-blocks rather than appending
     :type link: bool
     :param autoselect: Select, Select new objects
@@ -1351,8 +1356,8 @@ def open_mainfile(filepath: str = "",
                   filter_folder: bool = True,
                   filter_blenlib: bool = False,
                   filemode: int = 8,
-                  display_type: typing.Union[str, int] = 'DEFAULT',
-                  sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
+                  display_type: typing.Union[int, str] = 'DEFAULT',
+                  sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
                   load_ui: bool = True,
                   use_scripts: bool = True):
     ''' Open a Blender file
@@ -1388,9 +1393,9 @@ def open_mainfile(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     :param load_ui: Load UI, Load user interface setup in the .blend file
     :type load_ui: bool
     :param use_scripts: Trusted Source, Allow .blend file to execute scripts automatically, default available from system preferences
@@ -1455,8 +1460,10 @@ def path_open(filepath: str = ""):
 
 
 def previews_batch_clear(
-        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                            'bpy_prop_collection'] = None,
+        files: typing.
+        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+              List['bpy.types.OperatorFileListElement'],
+              'bpy_prop_collection'] = None,
         directory: str = "",
         filter_blender: bool = True,
         filter_folder: bool = True,
@@ -1469,7 +1476,7 @@ def previews_batch_clear(
     ''' Clear selected .blend file's previews
 
     :param files: files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param directory: directory
     :type directory: str
     :param filter_blender: filter_blender
@@ -1494,8 +1501,10 @@ def previews_batch_clear(
 
 
 def previews_batch_generate(
-        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                            'bpy_prop_collection'] = None,
+        files: typing.
+        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+              List['bpy.types.OperatorFileListElement'],
+              'bpy_prop_collection'] = None,
         directory: str = "",
         filter_blender: bool = True,
         filter_folder: bool = True,
@@ -1508,7 +1517,7 @@ def previews_batch_generate(
     ''' Generate selected .blend file's previews
 
     :param files: files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param directory: directory
     :type directory: str
     :param filter_blender: filter_blender
@@ -1532,14 +1541,14 @@ def previews_batch_generate(
     pass
 
 
-def previews_clear(id_type: typing.Union[typing.Set[str], typing.Set[int]] = {
+def previews_clear(id_type: typing.Union[typing.Set[int], typing.Set[str]] = {
         'GROUP', 'IMAGE', 'LAMP', 'MATERIAL', 'OBJECT', 'SCENE', 'TEXTURE',
         'WORLD'
 }):
     ''' Clear data-block previews (only for some types like objects, materials, textures, etc.)
 
     :param id_type: Data-Block Type, Which data-block previews to clear
-    :type id_type: typing.Union[typing.Set[str], typing.Set[int]]
+    :type id_type: typing.Union[typing.Set[int], typing.Set[str]]
     '''
 
     pass
@@ -1723,8 +1732,8 @@ def recover_auto_save(filepath: str = "",
                       filter_folder: bool = False,
                       filter_blenlib: bool = False,
                       filemode: int = 8,
-                      display_type: typing.Union[str, int] = 'LIST_LONG',
-                      sort_method: typing.Union[str, int] = 'FILE_SORT_TIME'):
+                      display_type: typing.Union[int, str] = 'LIST_LONG',
+                      sort_method: typing.Union[int, str] = 'FILE_SORT_TIME'):
     ''' Open an automatically saved file to recover it
 
     :param filepath: File Path, Path to file
@@ -1758,9 +1767,9 @@ def recover_auto_save(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
@@ -1774,13 +1783,13 @@ def recover_last_session():
     pass
 
 
-def redraw_timer(type: typing.Union[str, int] = 'DRAW',
+def redraw_timer(type: typing.Union[int, str] = 'DRAW',
                  iterations: int = 10,
                  time_limit: float = 0.0):
     ''' Simple redraw timer to test the speed of updating the interface
 
     :param type: Type * DRAW Draw Region, Draw Region. * DRAW_SWAP Draw Region + Swap, Draw Region and Swap. * DRAW_WIN Draw Window, Draw Window. * DRAW_WIN_SWAP Draw Window + Swap, Draw Window and Swap. * ANIM_STEP Anim Step, Animation Steps. * ANIM_PLAY Anim Play, Animation Playback. * UNDO Undo/Redo, Undo/Redo.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param iterations: Iterations, Number of times to redraw
     :type iterations: int
     :param time_limit: Time Limit, Seconds to run the test for (override iterations)
@@ -1816,8 +1825,8 @@ def save_as_mainfile(filepath: str = "",
                      filter_folder: bool = True,
                      filter_blenlib: bool = False,
                      filemode: int = 8,
-                     display_type: typing.Union[str, int] = 'DEFAULT',
-                     sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
+                     display_type: typing.Union[int, str] = 'DEFAULT',
+                     sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
                      compress: bool = False,
                      relative_remap: bool = True,
                      copy: bool = False,
@@ -1857,9 +1866,9 @@ def save_as_mainfile(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     :param compress: Compress, Write compressed .blend file
     :type compress: bool
     :param relative_remap: Remap Relative, Remap relative paths when saving in a different directory
@@ -1897,8 +1906,8 @@ def save_mainfile(filepath: str = "",
                   filter_folder: bool = True,
                   filter_blenlib: bool = False,
                   filemode: int = 8,
-                  display_type: typing.Union[str, int] = 'DEFAULT',
-                  sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
+                  display_type: typing.Union[int, str] = 'DEFAULT',
+                  sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
                   compress: bool = False,
                   relative_remap: bool = False):
     ''' Save the current Blender file
@@ -1936,9 +1945,9 @@ def save_mainfile(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     :param compress: Compress, Write compressed .blend file
     :type compress: bool
     :param relative_remap: Remap Relative, Remap relative paths when saving in a different directory
@@ -1964,19 +1973,19 @@ def search_menu():
     pass
 
 
-def set_stereo_3d(display_mode: typing.Union[str, int] = 'ANAGLYPH',
-                  anaglyph_type: typing.Union[str, int] = 'RED_CYAN',
-                  interlace_type: typing.Union[str, int] = 'ROW_INTERLEAVED',
+def set_stereo_3d(display_mode: typing.Union[int, str] = 'ANAGLYPH',
+                  anaglyph_type: typing.Union[int, str] = 'RED_CYAN',
+                  interlace_type: typing.Union[int, str] = 'ROW_INTERLEAVED',
                   use_interlace_swap: bool = False,
                   use_sidebyside_crosseyed: bool = False):
     ''' Toggle 3D stereo support for current window (or change the display mode)
 
     :param display_mode: Display Mode * ANAGLYPH Anaglyph, Render views for left and right eyes as two differently filtered colors in a single image (anaglyph glasses are required). * INTERLACE Interlace, Render views for left and right eyes interlaced in a single image (3D-ready monitor is required). * TIMESEQUENTIAL Time Sequential, Render alternate eyes (also known as page flip, quad buffer support in the graphic card is required). * SIDEBYSIDE Side-by-Side, Render views for left and right eyes side-by-side. * TOPBOTTOM Top-Bottom, Render views for left and right eyes one above another.
-    :type display_mode: typing.Union[str, int]
+    :type display_mode: typing.Union[int, str]
     :param anaglyph_type: Anaglyph Type
-    :type anaglyph_type: typing.Union[str, int]
+    :type anaglyph_type: typing.Union[int, str]
     :param interlace_type: Interlace Type
-    :type interlace_type: typing.Union[str, int]
+    :type interlace_type: typing.Union[int, str]
     :param use_interlace_swap: Swap Left/Right, Swap left and right stereo channels
     :type use_interlace_swap: bool
     :param use_sidebyside_crosseyed: Cross-Eyed, Right eye should see left image and vice-versa
